svpattern

Enum svpattern 

#[non_exhaustive]
#[repr(i32)]
pub enum svpattern {
Show 17 variants SV_POW2 = 0, SV_VL1 = 1, SV_VL2 = 2, SV_VL3 = 3, SV_VL4 = 4, SV_VL5 = 5, SV_VL6 = 6, SV_VL7 = 7, SV_VL8 = 8, SV_VL16 = 9, SV_VL32 = 10, SV_VL64 = 11, SV_VL128 = 12, SV_VL256 = 13, SV_MUL4 = 29, SV_MUL3 = 30, SV_ALL = 31,
}
🔬This is a nightly-only experimental API. (stdarch_aarch64_sve #145052)
Available on (AArch64 or ARM64EC) and (AArch64) only.
Patterns returned by a PTRUE

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


SV_POW2 = 0

🔬This is a nightly-only experimental API. (stdarch_aarch64_sve #145052)

Activate the largest power-of-two number of elements that is less than the vector length



SV_VL1 = 1

🔬This is a nightly-only experimental API. (stdarch_aarch64_sve #145052)

Activate the first element



SV_VL2 = 2

🔬This is a nightly-only experimental API. (stdarch_aarch64_sve #145052)

Activate the first two elements



SV_VL3 = 3

🔬This is a nightly-only experimental API. (stdarch_aarch64_sve #145052)

Activate the first three elements



SV_VL4 = 4

🔬This is a nightly-only experimental API. (stdarch_aarch64_sve #145052)

Activate the first four elements



SV_VL5 = 5

🔬This is a nightly-only experimental API. (stdarch_aarch64_sve #145052)

Activate the first five elements



SV_VL6 = 6

🔬This is a nightly-only experimental API. (stdarch_aarch64_sve #145052)

Activate the first six elements



SV_VL7 = 7

🔬This is a nightly-only experimental API. (stdarch_aarch64_sve #145052)

Activate the first seven elements



SV_VL8 = 8

🔬This is a nightly-only experimental API. (stdarch_aarch64_sve #145052)

Activate the first eight elements



SV_VL16 = 9

🔬This is a nightly-only experimental API. (stdarch_aarch64_sve #145052)

Activate the first sixteen elements



SV_VL32 = 10

🔬This is a nightly-only experimental API. (stdarch_aarch64_sve #145052)

Activate the first thirty-two elements



SV_VL64 = 11

🔬This is a nightly-only experimental API. (stdarch_aarch64_sve #145052)

Activate the first sixty-four elements



SV_VL128 = 12

🔬This is a nightly-only experimental API. (stdarch_aarch64_sve #145052)

Activate the first one-hundred-and-twenty-eight elements



SV_VL256 = 13

🔬This is a nightly-only experimental API. (stdarch_aarch64_sve #145052)

Activate the first two-hundred-and-fifty-six elements



SV_MUL4 = 29

🔬This is a nightly-only experimental API. (stdarch_aarch64_sve #145052)

Activate the largest multiple-of-four number of elements that is less than the vector length



SV_MUL3 = 30

🔬This is a nightly-only experimental API. (stdarch_aarch64_sve #145052)

Activate the largest multiple-of-three number of elements that is less than the vector length



SV_ALL = 31

🔬This is a nightly-only experimental API. (stdarch_aarch64_sve #145052)

Activate all elements