svprfop

Enum svprfop 

#[non_exhaustive]
#[repr(i32)]
pub enum svprfop { SV_PLDL1KEEP = 0, SV_PLDL1STRM = 1, SV_PLDL2KEEP = 2, SV_PLDL2STRM = 3, SV_PLDL3KEEP = 4, SV_PLDL3STRM = 5, SV_PSTL1KEEP = 8, SV_PSTL1STRM = 9, SV_PSTL2KEEP = 10, SV_PSTL2STRM = 11, SV_PSTL3KEEP = 12, SV_PSTL3STRM = 13, }
🔬This is a nightly-only experimental API. (stdarch_aarch64_sve #145052)
Available on (AArch64 or ARM64EC) and (AArch64) only.
Addressing mode for prefetch intrinsics - allows the specification of the expected access kind (read or write), the cache level to load the data, the data retention policy (temporal or streaming)

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


SV_PLDL1KEEP = 0

🔬This is a nightly-only experimental API. (stdarch_aarch64_sve #145052)

Temporal fetch of the addressed location for reading to the L1 cache (i.e. allocate in cache normally)



SV_PLDL1STRM = 1

🔬This is a nightly-only experimental API. (stdarch_aarch64_sve #145052)

Streaming fetch of the addressed location for reading to the L1 cache (i.e. memory only used once)



SV_PLDL2KEEP = 2

🔬This is a nightly-only experimental API. (stdarch_aarch64_sve #145052)

Temporal fetch of the addressed location for reading to the L2 cache (i.e. allocate in cache normally)



SV_PLDL2STRM = 3

🔬This is a nightly-only experimental API. (stdarch_aarch64_sve #145052)

Streaming fetch of the addressed location for reading to the L2 cache (i.e. memory only used once)



SV_PLDL3KEEP = 4

🔬This is a nightly-only experimental API. (stdarch_aarch64_sve #145052)

Temporal fetch of the addressed location for reading to the L3 cache (i.e. allocate in cache normally)



SV_PLDL3STRM = 5

🔬This is a nightly-only experimental API. (stdarch_aarch64_sve #145052)

Streaming fetch of the addressed location for reading to the L3 cache (i.e. memory only used once)



SV_PSTL1KEEP = 8

🔬This is a nightly-only experimental API. (stdarch_aarch64_sve #145052)

Temporal fetch of the addressed location for writing to the L1 cache (i.e. allocate in cache normally)



SV_PSTL1STRM = 9

🔬This is a nightly-only experimental API. (stdarch_aarch64_sve #145052)

Temporal fetch of the addressed location for writing to the L1 cache (i.e. memory only used once)



SV_PSTL2KEEP = 10

🔬This is a nightly-only experimental API. (stdarch_aarch64_sve #145052)

Temporal fetch of the addressed location for writing to the L2 cache (i.e. allocate in cache normally)



SV_PSTL2STRM = 11

🔬This is a nightly-only experimental API. (stdarch_aarch64_sve #145052)

Temporal fetch of the addressed location for writing to the L2 cache (i.e. memory only used once)



SV_PSTL3KEEP = 12

🔬This is a nightly-only experimental API. (stdarch_aarch64_sve #145052)

Temporal fetch of the addressed location for writing to the L3 cache (i.e. allocate in cache normally)



SV_PSTL3STRM = 13

🔬This is a nightly-only experimental API. (stdarch_aarch64_sve #145052)

Temporal fetch of the addressed location for writing to the L3 cache (i.e. memory only used once)