pub fn vcombine_u16(a: uint16x4_t, b: uint16x4_t) -> uint16x8_tAvailable on (AArch64 or ARM64EC) and target feature
neon only.Expand description
Join two smaller vectors into a single larger vector Arm’s documentation
pub fn vcombine_u16(a: uint16x4_t, b: uint16x4_t) -> uint16x8_tneon only.Join two smaller vectors into a single larger vector Arm’s documentation