pub fn vcombine_u64(a: uint64x1_t, b: uint64x1_t) -> uint64x2_tAvailable on (AArch64 or ARM64EC) and target feature
neon only.Expand description
Join two smaller vectors into a single larger vector Arm’s documentation
pub fn vcombine_u64(a: uint64x1_t, b: uint64x1_t) -> uint64x2_tneon only.Join two smaller vectors into a single larger vector Arm’s documentation